==> openser_1.2.1.orig.tar.gz: openser-1.2.1-tls/db/db_res.h <==
/* 
 * $Id: db_res.h 1827 2007-03-12 15:22:53Z bogdan_iancu $ 
 *
 * Copyright (C) 2001-2003 FhG Fokus
 *
 * This file is part of openser, a free SIP server.
 *
 * openser is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version
 *
 * openser is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with this program; if not, write to the Free Software 
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */


#ifndef DB_RES_H
#define DB_RES_H


#include "db_row.h"
#include "db_key.h"
#include "db_val.h"


typedef struct db_res {
	struct {
		db_key_t* names;   /* Column names */
		db_type_t* types;  /* Column types */
		int n;             /* Number of columns */
	} col;
	struct db_row* rows;       /* Rows */
	int n;                     /* Number of rows in current fetch */
	int res_rows;              /* Number of total rows in query */
	int last_row;              /* Last row */
} db_res_t;


#define RES_NAMES(re) ((re)->col.names)
#define RES_TYPES(re) ((re)->col.types)
#define RES_COL_N(re) ((re)->col.n)
#define RES_ROWS(re)  ((re)->rows)
#define RES_ROW_N(re) ((re)->n)
#define RES_LAST_ROW(re)  ((re)->last_row)
#define RES_NUM_ROWS(re) ((re)->res_rows)


#endif /* DB_RES_H */

==> openser_1.3.2.orig.tar.gz: openser-1.3.2-tls/db/db_res.h <==
/* 
 * $Id: db_res.h 2871 2007-10-05 14:32:16Z henningw $ 
 *
 * Copyright (C) 2001-2003 FhG Fokus
 *
 * This file is part of openser, a free SIP server.
 *
 * openser is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version
 *
 * openser is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with this program; if not, write to the Free Software 
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */


#ifndef DB_RES_H
#define DB_RES_H


#include "db_row.h"
#include "db_key.h"
#include "db_val.h"


typedef struct db_res {
	struct {
		db_key_t* names;   /* Column names */
		db_type_t* types;  /* Column types */
		int n;             /* Number of columns */
	} col;
	struct db_row* rows;       /* Rows */
	int n;                     /* Number of rows in current fetch */
	int res_rows;              /* Number of total rows in query */
	int last_row;              /* Last row */
} db_res_t;


#define RES_NAMES(re) ((re)->col.names)
#define RES_TYPES(re) ((re)->col.types)
#define RES_COL_N(re) ((re)->col.n)
#define RES_ROWS(re)  ((re)->rows)
#define RES_ROW_N(re) ((re)->n)
#define RES_LAST_ROW(re)  ((re)->last_row)
#define RES_NUM_ROWS(re) ((re)->res_rows)

/*
 * Release memory used by rows in a result structure
 */
int db_free_rows(db_res_t* _r);

/*
 * Create a new result structure and initialize it
 */
inline db_res_t* db_new_result(void);

#endif /* DB_RES_H */
